@@ -1,6 +1,6 @@
 from attr import attrs, attrib
 
-from . import AliceObject, MediaButton
+from aioalice.types import AliceObject, MediaButton
 from aioalice.utils import ensure_cls
 
 
@@ -8,4 +8,4 @@ from aioalice.utils import ensure_cls
 class CardFooter(AliceObject):
     """This object represents a card's footer"""
     text = attrib(type=str)
-    button = attrib(default=None, convert=ensure_cls(MediaButton))
+    button = attrib(default=None, converter=ensure_cls(MediaButton))
