@@ -1,5 +1,7 @@
 from attr import attrs, attrib
-from . import AliceObject
+
+from aioalice.types import AliceObject, Interfaces
+from aioalice.utils import ensure_cls
 
 
 @attrs
@@ -8,4 +10,5 @@ class Meta(AliceObject):
     locale = attrib(type=str)
     timezone = attrib(type=str)
     client_id = attrib(type=str)
+    interfaces = attrib(default=None, converter=ensure_cls(Interfaces))
     flags = attrib(factory=list)
