@@ -1,5 +1,6 @@
 from attr import attrs, attrib
-from . import AliceObject
+
+from aioalice.types import AliceObject
 
 
 @attrs
@@ -21,5 +22,5 @@ class Session(BaseSession):
         return BaseSession(
             self.session_id,
             self.message_id,
-            self.user_id
+            self.user_id,
         )
